@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::Minion::Workers;
 use Mojo::Base 'Mojolicious::Plugin::Minion';
 
-our $VERSION = '0.9092';# as to Minion version/10+<child minor>
+our $VERSION = '0.9093';# as to Minion version/10+<child minor>
 
 has minion => undef, weak=>1;
 has qw(conf);
@@ -122,7 +122,7 @@ sub worker_run {
 sub kill_workers {
   my ($self, $workers) = @_;
   my $minion = $self->minion;
-  $workers ||= $minion->backend->list_workers->{workers};
+  $workers ||= $minion->backend->list_workers(0,1000)->{workers};
 
   kill 'QUIT', $_->{pid}
     and $minion->app->log->info("Minion worker (pid $_->{pid}) was stopped")
